import pandas as pd

from .get_info import get_employees_number



def get_employees_counts(apikey: str='apikey', ticks: list=['AAPL', 'MSFT'], period: str = 'annual', 
           with_progress: bool = False):
    
    """
    params:
        apikey -- to access data from FMP;
        ticks -- list of tickers;
        period -- either 'annual' or 'quarter';
        with_progress -- if you want to visualize progress;
    return: data frame of employees number
    """
    
    if with_progress:
        n = len(ticks)
        i=0

    employees = []

    for ticker in ticks:
        try:
            ticker_data = get_employees_number(apikey=apikey, symbol=ticker)
            employees.append(pd.DataFrame(ticker_data))
            if with_progress:
                i += 1
                print(f"For {ticker}: {i} / {n}")
        except:
            pass

    employees_df = pd.concat(employees, axis=0)

    return employees_df


import pandas as pd

from ..courtois.fmp_url import get_data_url

from datetime import datetime
from dateutil.relativedelta import relativedelta

def company_profile(apikey: str='apikey', symbol: str='AAPL'):
    """
    params:
        apikey -- to access data from FMP;
        symbol -- ticker of company;
    return: list of dictionaries
    """
    url = (f'https://financialmodelingprep.com/api/v3/profile/{symbol}?apikey={apikey}')
    data = get_data_url(url=url)
    return data

def get_fs_some(apikey: str='apikey', symbol: str='AAPL', period: str='annual',
                limit: int=10, finance: str='balance-sheet-statement'):
    """
    params:
        apikey -- to access data from FMP;
        symbol -- ticker of company;
        period -- either 'annual' or 'quarter';
        limit -- number of data points;
        finance -- can be 'balance-sheet-statement', or 'income-statement', or 'cash-flow-statement', or 'enterprise-values', 
            or 'ratios'
    return: list of dictionaries
    """
    url = (f'https://financialmodelingprep.com/api/v3/{finance}/{symbol}?period={period}&limit={limit}&apikey={apikey}')
    data = get_data_url(url=url)
    return data

def get_employees_number(apikey: str='apikey', symbol: str='AAPL'):
    """
    params:
        apikey -- to access data from FMP;
        symbol -- ticker of company;
    return: list of dictionaries
    """

    url = (f"https://financialmodelingprep.com/api/v4/historical/employee_count?symbol={symbol}&apikey={apikey}")
    data = get_data_url(url=url)
    return data


from ..courtois.fmp_url import get_data_url

def earning_transcript(apikey: str='apikey', symbol: str='AAPL', year: int=2020, quarter: int=4):
    """
    params:
        apikey -- to access data from FMP;
        symbol -- ticker of company;
    return: list of dictionaries
    """
    
    url = (f"https://financialmodelingprep.com/api/v3/earning_call_transcript/{symbol}?year={year}&quarter={quarter}&apikey={apikey}")

    data = get_data_url(url=url)

    return data

def general_news(apikey: str='apikey', page: int=1):
    """
    params:
        apikey -- to access data from FMP;
        page -- page;
    return: list of dictionaries
    """
    
    url = (f"https://financialmodelingprep.com/api/v4/general_news?page={page}&apikey={apikey}")

    data = get_data_url(url=url)

    return data

def fmp_articles(apikey: str='apikey', page: int=1, size: int=5):
    """
    params:
        apikey -- to access data from FMP;
        page -- page;
        size -- number of items in the page
    return: list of dictionaries
    """
    
    url = (f"https://financialmodelingprep.com/api/v3/fmp/articles?page={page}&size={size}&apikey={apikey}")

    data = get_data_url(url=url)

    return data

def stock_news(apikey: str='apikey', page: int=1):
    """
    params:
        apikey -- to access data from FMP;
        page -- page;
    return: list of dictionaries
    """
    
    url = (f"https://financialmodelingprep.com/api/v3/stock_news?page={page}&apikey={apikey}")

    data = get_data_url(url=url)

    return data

def sentiments(apikey: str='apikey', page: int=1):
    """
    params:
        apikey -- to access data from FMP;
        page -- page;
    return: list of dictionaries
    """
    
    url = (f"https://financialmodelingprep.com/api/v4/stock-news-sentiments-rss-feed?page={page}&apikey={apikey}")

    data = get_data_url(url=url)

    return data

def press_releases(apikey: str='apikey', symbol: str='AAPL'):
    """
    params:
        apikey -- to access data from FMP;
        page -- page;
    return: list of dictionaries
    """
    
    url = (f"https://financialmodelingprep.com/api/v3/press-releases/{symbol}?apikey={apikey}")

    data = get_data_url(url=url)

    return data



